pub struct OutputNode {
id: NodeId,
source: NodeId,
_zero: bool,
}Expand description
the node that represents the output of a circuit
Fields
id: NodeIdsource: NodeId_zero: boolImplementations
Sourceimpl OutputNode
impl OutputNode
Sourcepub fn new(source: &impl CircuitNode) -> Self
pub fn new(source: &impl CircuitNode) -> Self
Creates a new OutputNode from a source w/ some data
Sourcepub fn new_zero(source: &dyn CircuitNode) -> Self
pub fn new_zero(source: &dyn CircuitNode) -> Self
Creates a new ZeroMleRef, which constrains the source to equal a Zero Mle
Sourcepub fn generate_circuit_description<F: Field>(
&self,
circuit_map: &mut CircuitMap,
) -> Result<OutputLayerDescription<F>>
pub fn generate_circuit_description<F: Field>( &self, circuit_map: &mut CircuitMap, ) -> Result<OutputLayerDescription<F>>
Using the CircuitMap, create a [OutputLayerDescription] which represents the circuit description of an OutputNode.